==> data-0.10.0.tar.gz: lib/src/stats/distributions/discrete/uniform.dart <==
import 'dart:math';

import '../continuous/uniform.dart';
import '../discrete.dart';

/// A discrete uniform distribution between [a] and [b], for details see
/// https://en.wikipedia.org/wiki/Discrete_uniform_distribution.
class UniformDiscreteDistribution extends DiscreteDistribution {
  const UniformDiscreteDistribution(this.a, this.b) : assert(a <= b, 'a <= b');

  /// Minimum value of the distribution.
  final int a;

  /// Maximum value of the distribution.
  final int b;

  // Returns the number of elements in this distribution.
  int get count => b - a + 1;

  @override
  int get lowerBound => a;

  @override
  int get upperBound => b;

  @override
  double get mean => 0.5 * (a + b);

  @override
  double get median => mean;

  @override
  double get mode => double.nan;

  @override
  double get variance => (count * count - 1) / 12;

  @override
  double probability(int k) => a <= k && k <= b ? 1.0 / count : 0.0;

  @override
  double cumulativeProbability(int k) => k < a
      ? 0.0
      : k <= b
          ? (k - a + 1) / count
          : 1.0;

  @override
  int sample({Random? random}) {
    const uniform = UniformDistribution.standard();
    return a + (count * uniform.sample(random: random)).floor();
  }

  @override
  bool operator ==(Object other) =>
      other is UniformDiscreteDistribution && a == other.a && b == other.b;

  @override
  int get hashCode => Object.hash(UniformDiscreteDistribution, a, b);

  @override
  String toString() => 'UniformDiscreteDistribution[$a..$b]';
}

==> data-0.12.0.tar.gz: lib/src/stats/distributions/discrete/uniform.dart <==
import 'dart:math';

import 'package:more/interval.dart';
import 'package:more/printer.dart';

import '../continuous/uniform.dart';
import '../discrete.dart';

/// A discrete uniform distribution between [a] and [b], for details see
/// https://en.wikipedia.org/wiki/Discrete_uniform_distribution.
class UniformDiscreteDistribution extends DiscreteDistribution {
  /// A discrete uniform distribution between [a] and [b].
  const UniformDiscreteDistribution(this.a, this.b) : assert(a <= b, 'a <= b');

  /// Minimum value of the distribution.
  final int a;

  /// Maximum value of the distribution.
  final int b;

  // Returns the number of elements in this distribution.
  int get n => b - a + 1;

  @override
  Interval<int> get support => Interval<int>.closed(a, b);

  @override
  double get mean => 0.5 * (a + b);

  @override
  double get median => mean;

  @override
  double get mode => double.nan;

  @override
  double get variance => (n * n - 1) / 12;

  @override
  double get skewness => 0;

  @override
  double get kurtosisExcess => -6 / 5 * (n * n + 1) / (n * n - 1);

  @override
  double probability(int k) => a <= k && k <= b ? 1 / n : 0;

  @override
  double cumulativeProbability(int k) => k < a
      ? 0
      : k <= b
          ? (k - a + 1) / n
          : 1;

  @override
  int sample({Random? random}) {
    const uniform = UniformDistribution.standard();
    return a + (n * uniform.sample(random: random)).floor();
  }

  @override
  bool operator ==(Object other) =>
      other is UniformDiscreteDistribution && a == other.a && b == other.b;

  @override
  int get hashCode => Object.hash(UniformDiscreteDistribution, a, b);

  @override
  ObjectPrinter get toStringPrinter => super.toStringPrinter
    ..addValue(a, name: 'a')
    ..addValue(b, name: 'b')
    ..addValue(n, name: 'n');
}
